2.0
==================

* Better cancellation handling
* Breaking change: ``concurrent`` now takes a
  ``exception_handling`` param instead of ``return_exceptions``

1.0
==================

* Initial release
